<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN" sourcelanguage="zh_CN">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>浏览器之外，生活亦精彩！</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 是自由软件。其开发也同样要耗用宝贵时间的。</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>恭迎您慷慨&lt;a href=&apos;%1&apos;&gt;捐赠&lt;/a&gt;，支持我们继续开发 %2 。</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>软件错误和建议敬请发送到：%1</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>图标设计：%1。</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>简洁模式贡献者：%1。</translation>
    </message>
    <message>
        <source>HTTP proxy support contributed by %1.</source>
        <translation>HTTP代理支持贡献者：%1。</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>翻译：%1 。</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>本软件遵循&lt;a href=&apos;%1&apos;&gt;GNU通用公共许可证&lt;/a&gt;予以发布。</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>您对 %1 的期望都有什么，还请不吝赐教。</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>字节</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>千字节</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>兆字节</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>字节/秒</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>千字节/秒</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>兆字节/秒</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>分</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 剩余</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>下载数：%n</numerusform>
        </translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>这只是 %1 的演示版。</translation>
    </message>
    <message>
        <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
        <translation>本版本只能下载 %1 分钟以下的视频，仅用于测试下载功能。</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>获取完整版</translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>更改存储位置……</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>选择下载存储位置</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>下载存储位置已修改。</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>当前下载仍然保持前一个存储位置。</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>当前下载存储位置：%1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>下载情况</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>播放/暂停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>当前轨道后停止播放</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>下一轨道</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>上一轨道</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>调高音量</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>调低音量</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>向前搜索</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>向后搜索</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>搜索中……</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>再多显示 %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>没有视频</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>没有更多视频</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Stop</source>
        <translation>停止(&amp;S)</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>停止回放并返回搜索视图</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>跳过(&amp;k)</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>跳至下一视频</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>暂停(&amp;P)</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>暂停回放</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>全屏播放</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>简洁模式(&amp;C)</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>隐藏播放列表和工具栏</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube page</source>
        <translation>打开YouTube页面(&amp;Y)</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>打开YouTube视频页面并暂停回放</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;link</source>
        <translation>复制YouTube链接(&amp;l)</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>复制当前视频的YouTube链接到剪贴板中</translation>
    </message>
    <message>
        <source>Copy the video stream &amp;URL</source>
        <translation>复制视频流的URL链接(&amp;U)</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>复制当前视频流的URL到剪贴板中</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>从播放列表中移除选定的视频</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>上移(&amp;U)</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>在播放列表中向上移动选定的视频</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>下移(&amp;D)</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>在播放列表中向下移动选定的视频</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation type="obsolete">清除最近使用的关键字词(&amp;C)</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>清除搜索历史。注意：清除的历史不可恢复。</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>再会</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>网站(&amp;W)</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1在网站上</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>敬请捐赠(&amp;d)</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>请您支持 %1 的可持续发展。</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>关于 %1 的信息</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>应用程序(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>播放列表(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>视频(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>按住 %1 提高音量，%2 降低音量</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>正在打开 %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>严重错误：%1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>错误：%1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>播放(&amp;P)</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>继续回放</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>退出全屏(&amp;F)</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>剩余时间：%1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>音量：%1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>已设为静音</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>静音已解除</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>最大视频定义设置为%1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>您的隐私已受保护</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>下载(&amp;D)</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>显示视频下载详情</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>下载(&amp;D)</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>下载当前视频</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>当前还有尚未完成的下载。您确定要退出 %1 吗？</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>如果您现在关闭 %1 ，那么本下载将被取消。</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>关闭并取消下载</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>等待下载完成</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>下载完成</translation>
    </message>
    <message>
        <source>&amp;Clear recent searches</source>
        <translation>清除最近的检索(&amp;C)</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>相关最多</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>最近</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>观看最多</translation>
    </message>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>您现在可以把YouTube的链接粘贴到其他应用了</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>您现在可以把视频流的链接粘贴到其他应用了</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>此链接仅能保持短时间的有效性。</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation type="obsolete">您正在观看“%1”</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>这仅是 %1 的演示版。</translation>
    </message>
    <message>
        <source>It allows you to test the application and see if it works for you.</source>
        <translation>本版本允许您测试，以确认本应用是否适合您。</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>获取完整版</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>正在下载 %1</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>网络错误：%1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 人次观看</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>准备中</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>已失败</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>已完成</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>已停止</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>停止下载</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>显示到 %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>打开上层目录</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>重新下载</translation>
    </message>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 之 %2 (%3) — %4</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>欢迎使用&lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;！</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation type="obsolete">请输入一个关键字词以开始观看视频。</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>观看</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>最近关键字词</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>%1 已有新版本。敬请&lt;a href=&apos;%2&apos;&gt;更新到版本 %3&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>请您尽情享受吧！</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>获取完整版</translation>
    </message>
    <message>
        <source>Enter</source>
        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
        <translation>输入</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>关键字</translation>
    </message>
    <message>
        <source>a channel</source>
        <translation>频道名称</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>开始观看视频。</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>最近频道</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>网络错误：%1。可能原因：%2</translation>
    </message>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>无法获得视频流。可能原因：%1</translation>
    </message>
</context>
</TS>
